@@ -18,6 +18,7 @@
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2019 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2021 Federico Bond <federicobond@gmail.com>
 # Copyright (c) 2021 hippo91 <guillaume.peillex@gmail.com>
@@ -45,11 +46,11 @@ from typing import (
     overload,
 )
 
-from astroid import node_classes, nodes
+from astroid import nodes
 from astroid._ast import ParserModule, get_parser_module, parse_function_type_comment
 from astroid.const import PY37_PLUS, PY38_PLUS, PY39_PLUS, Context
 from astroid.manager import AstroidManager
-from astroid.node_classes import NodeNG
+from astroid.nodes import NodeNG
 
 if sys.version_info >= (3, 8):
     from typing import Final
@@ -477,7 +478,7 @@ class TreeRebuilder:
             ...
 
         @overload
-        def visit(self, node: "ast.pattern", parent: NodeNG) -> node_classes.Pattern:
+        def visit(self, node: "ast.pattern", parent: NodeNG) -> nodes.Pattern:
             ...
 
         @overload
@@ -800,7 +801,7 @@ class TreeRebuilder:
             return visit_method(node, parent)
 
     def _save_assignment(self, node: Union[nodes.AssignName, nodes.DelName]) -> None:
-        """save assignement situation since node.parent is not available yet"""
+        """save assignment situation since node.parent is not available yet"""
         if self._global_names and node.name in self._global_names[-1]:
             node.root().set_local(node.name, node)
         else:
@@ -1215,7 +1216,7 @@ class TreeRebuilder:
     ) -> nodes.Tuple:
         """visit an ExtSlice node by returning a fresh instance of Tuple"""
         newnode = nodes.Tuple(ctx=Context.Load, parent=parent)
-        newnode.postinit([self.visit(dim, newnode) for dim in node.dims])  # type: ignore
+        newnode.postinit([self.visit(dim, newnode) for dim in node.dims])  # type: ignore[attr-defined]
         return newnode
 
     @overload
@@ -1434,7 +1435,7 @@ class TreeRebuilder:
     # Not used in Python 3.9+.
     def visit_index(self, node: "ast.Index", parent: nodes.Subscript) -> NodeNG:
         """visit a Index node by returning a fresh instance of NodeNG"""
-        return self.visit(node.value, parent)  # type: ignore
+        return self.visit(node.value, parent)  # type: ignore[attr-defined]
 
     def visit_keyword(self, node: "ast.keyword", parent: NodeNG) -> nodes.Keyword:
         """visit a Keyword node by returning a fresh instance of it"""
